spacepy.data_assimilation.getobs4window — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- data assimilation - data assimilation module »

# spacepy.data_assimilation.getobs4window

`spacepy.data_assimilation.` `getobs4window`(dd, Tnow)

  get observations in time window [Tnow - Twindow, Tnow] from all satellites lumped together into one y vector

  Parameters: | model : : PSDdata : : HAp : :
  Returns: | out : :

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- data assimilation - data assimilation module »